import { Request, Response, Router } from "express";
import { createProject, deleteProject, patchProject, regenerateKey } from "@controller/projects";
import { validateSchema } from "@utils/error";
import { patchProjectValidation, projectCreationValidation } from "./validations/project";

const app: Router = Router();

app.put("/", async (req: Request, res: Response) => {
    if (validateSchema(res, projectCreationValidation, req.body)) return;

    const creationError = await createProject(req.body.name, String(req.user?._id));
    if (creationError) return res.json(creationError);

    res.json({ message: "Your project has been successfully created" });
});

app.delete("/:id", async (req: Request, res: Response) => {
    const deletionError = await deleteProject(req.params.id);
    if (deletionError) return res.json(deletionError);

    res.json({ message: "The project has been successfully deleted" });
});

app.patch("/:id", async (req: Request, res: Response) => {
    if (validateSchema(res, patchProjectValidation, req.body)) return;

    const patchError = await patchProject(req.params.id, req.body);
    if (patchError) return res.json(patchError);

    res.json({ message: "The project has been successfully updated" });
});

app.post("/:id/regenerate", async (req: Request, res: Response) => {
    const tokenError = await regenerateKey(req.params.id);
    if (tokenError) return res.json(tokenError);

    res.json({ message: "The validation key has been regenerated" });
});

export default app;